==> artemis_cupps-0.0.28.tar.gz: lib/classes/Devices/ms_device.dart <==
import 'dart:developer';

import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../../constants.dart';
import '../classes.dart';

class MsDevice extends Device {
  MsDevice(
      {required MsDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory MsDevice.fromDevice(Device d) {
    return MsDevice(
      deviceParameter: MsDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
  Future<CuppsCommandResponse> lockDevice() async {
    CuppsCommandResponse lockRes = await lock();
    log("$lockRes");
    return lockRes;
    // print(lockRes);
  }

  Future<CuppsCommandResponse> unlockDevice() async {
    CuppsCommandResponse unlockRes = await unlock();
    log("$unlockRes");
    return unlockRes;
    // print(lockRes);
  }
}

class MsDeviceParameter extends DeviceParameter {
  final String numberOfTracks;
  final String supportsJIS2;
  final String style;
  final String msCapabilities;

  MsDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.numberOfTracks,
    required this.supportsJIS2,
    required this.style,
    required this.msCapabilities,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory MsDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("msStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    MsStatus status = MsStatus.fromXML(statusElement!.toXmlString());

    String numberOfTracks = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "numberOfTracks")
        .value;
    String supportsJIS2 = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "supportsJIS2")
        .value;
    String style = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "style")
        .value;
    String msCapabilities = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "msCapabilities",
            orElse: orElseEmpty)
        .value;
    return MsDeviceParameter(
      vendorModelInfo: vendorModelInfo,
      ipAndPort: ipAndPort,
      status: status,
      numberOfTracks: numberOfTracks,
      supportsJIS2: supportsJIS2,
      style: style,
      msCapabilities: msCapabilities,
    );
  }

  @override
  String toXML() {
    return '''
    <msDeviceParameter numberOfTracks="$numberOfTracks" supportsJIS2="$supportsJIS2" style="$style" ${msCapabilities.isEmpty ? "" : 'msCapabilities="$msCapabilities"'} >
    ${vendorModelInfo.toXML()}
    ${ipAndPort.toXML()}
    ${status.toXML()}
    </msDeviceParameter>
    ''';
  }
}

class MsStatus extends Status {
  MsStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory MsStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    return MsStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown);
  }

  @override
  String toXML() {
    return '''<msStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown"/>''';
  }

  @override
  String get image {
    if (isOff) return AssetImages.msIconsAddressDisconnect;
    if (isLocked) return AssetImages.msIconsAddressLocked;
    if (isInit) return AssetImages.msIconsAddressIn;
    if (isReady) return AssetImages.msIconsAddressActive;
    return AssetImages.msIconsAddressNatural;
  }
}

==> artemis_cupps-0.0.41.tar.gz: lib/classes/Devices/ms_device.dart <==
import 'dart:developer';

import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../../constants.dart';
import '../classes.dart';

class MsDevice extends Device {
  MsDevice(
      {required MsDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory MsDevice.fromDevice(Device d) {
    return MsDevice(
      deviceParameter: MsDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
  Future<CuppsCommandResponse> lockDevice() async {
    CuppsCommandResponse lockRes = await lock();
    log("$lockRes");
    return lockRes;
    // print(lockRes);
  }

  Future<CuppsCommandResponse> unlockDevice() async {
    CuppsCommandResponse unlockRes = await unlock();
    log("$unlockRes");
    return unlockRes;
    // print(lockRes);
  }
}

class MsDeviceParameter extends DeviceParameter {
  final String numberOfTracks;
  final String supportsJIS2;
  final String style;
  final String msCapabilities;

  MsDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
    required this.numberOfTracks,
    required this.supportsJIS2,
    required this.style,
    required this.msCapabilities,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory MsDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("msStatus");

    VendorModelInfo vendorModelInfo =
        VendorModelInfo.fromXML(vendorModelInfoElement!.toXmlString());
    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    MsStatus status = MsStatus.fromXML(statusElement!.toXmlString());

    String numberOfTracks = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "numberOfTracks")
        .value;
    String supportsJIS2 = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "supportsJIS2")
        .value;
    String style = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "style")
        .value;
    String msCapabilities = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "msCapabilities",
            orElse: orElseEmpty)
        .value;
    return MsDeviceParameter(
      vendorModelInfo: vendorModelInfo,
      ipAndPort: ipAndPort,
      status: status,
      numberOfTracks: numberOfTracks,
      supportsJIS2: supportsJIS2,
      style: style,
      msCapabilities: msCapabilities,
    );
  }

  @override
  String toXML() {
    return '''<msDeviceParameter numberOfTracks="$numberOfTracks" supportsJIS2="$supportsJIS2" style="$style" ${msCapabilities.isEmpty ? "" : 'msCapabilities="$msCapabilities"'} >
    ${vendorModelInfo.toXML()}
    ${ipAndPort.toXML()}
    ${status.toXML()}
    </msDeviceParameter>
    ''';
  }
}

class MsStatus extends Status {
  MsStatus({
    required String desc,
    required String init,
    required String powerOff,
    required String ready,
    required String unknown,
  }) : super(
            desc: desc,
            init: init,
            powerOff: powerOff,
            ready: ready,
            unknown: unknown);

  factory MsStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String powerOff = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "powerOff")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    return MsStatus(
        desc: desc,
        init: init,
        powerOff: powerOff,
        ready: ready,
        unknown: unknown);
  }

  @override
  String toXML() {
    return '''<msStatus desc="$desc" init="$init" powerOff="$powerOff" ready="$ready" unknown="$unknown"/>''';
  }

  @override
  String get image {
    if (isOff) return AssetImages.msIconsAddressDisconnect;
    if (isLocked) return AssetImages.msIconsAddressLocked;
    if (isInit) return AssetImages.msIconsAddressIn;
    if (isReady) return AssetImages.msIconsAddressActive;
    return AssetImages.msIconsAddressNatural;
  }
}
